@@ -38,22 +38,19 @@ def lambda_handler(event: Dict[str, Any], context: Any) -> None:
 
     uncleared = []
 
-    # first prune metadata - if clears below are partial we want to make sure no clients
-    # consider this a valid graph still.
-    logger.info(event=LogEvent.PruneNeptuneMetadataGraphStart)
-    client.clear_old_graph_metadata(name=config.graph_name, max_age_min=config.pruner_max_age_min)
-    logger.info(event=LogEvent.PruneNeptuneMetadataGraphEnd)
-    # now clear actual graphs
+    logger.info(event=LogEvent.PruneNeptuneGraphsStart)
+    all_graph_metadatas = client.get_graph_metadatas(name=config.graph_name)
     with logger.bind(neptune_endpoint=str(endpoint)):
-        logger.info(event=LogEvent.PruneNeptuneGraphsStart)
-        for graph_metadata in client.get_graph_metadatas(name=config.graph_name):
+        for graph_metadata in all_graph_metadatas:
             assert graph_metadata.name == config.graph_name
             graph_epoch = graph_metadata.end_time
             with logger.bind(graph_uri=graph_metadata.uri, graph_epoch=graph_epoch):
                 if graph_epoch < oldest_acceptable_graph_epoch:
                     logger.info(event=LogEvent.PruneNeptuneGraphStart)
                     try:
-                        client.clear_graph(graph_uri=graph_metadata.uri)
+                        client.clear_registered_graph(
+                            name=config.graph_name, uri=graph_metadata.uri
+                        )
                         logger.info(event=LogEvent.PruneNeptuneGraphEnd)
                     except Exception as ex:
                         logger.error(
@@ -64,6 +61,24 @@ def lambda_handler(event: Dict[str, Any], context: Any) -> None:
                         continue
                 else:
                     logger.info(event=LogEvent.PruneNeptuneGraphSkip)
+        # now find orphaned graphs - these are in neptune but have no metadata
+        registered_graph_uris = [g_m.uri for g_m in all_graph_metadatas]
+        all_graph_uris = client.get_graph_uris(name=config.graph_name)
+        orphaned_graphs = set(all_graph_uris) - set(registered_graph_uris)
+        if orphaned_graphs:
+            for orphaned_graph_uri in orphaned_graphs:
+                with logger.bind(graph_uri=orphaned_graph_uri):
+                    logger.info(event=LogEvent.PruneOrphanedNeptuneGraphStart)
+                    try:
+                        client.clear_graph_data(uri=orphaned_graph_uri)
+                        logger.info(event=LogEvent.PruneOrphanedNeptuneGraphEnd)
+                    except Exception as ex:
+                        logger.error(
+                            event=LogEvent.PruneNeptuneGraphError,
+                            msg=f"Error pruning graph {orphaned_graph_uri}: {ex}",
+                        )
+                        uncleared.append(orphaned_graph_uri)
+                        continue
         logger.info(event=LogEvent.PruneNeptuneGraphsEnd)
         if uncleared:
             msg = f"Errors were found pruning {uncleared}."
